Installation — django-nomad-notifier 0.1 documentation

### Navigation

- index
- previous |
- django-nomad-notifier 0.1 documentation »

# Installation

## Initial setup

The package is listed in the Python Package Index. You can use your favorite package manager like `easy_install` or `pip`:

    pip install django-nomad-notifier

Or, you can clone the latest development code from its repository:

    git clone git@github.com:Nomadblue/django-nomad-notifier.git

Add `notifier` to the `INSTALLED_APPS` setting of your `settings.py`:

    INSTALLED_APPS = (
        ...
        'notifier',
    )

### Navigation

- index
- previous |
- django-nomad-notifier 0.1 documentation »